#include "BasicHwShader.h"
#include <maya/MFnPlugin.h>

// required to link the libraries under VisualC++/Win32
#ifdef WIN32
	#pragma comment(lib,"Foundation.lib")
	#pragma comment(lib,"OpenMaya.lib")
	#pragma comment(lib,"OpenMayaFx.lib")
	#pragma comment(lib,"OpenMayaUi.lib")
	#pragma comment(lib,"Image.lib")
	#pragma comment(lib,"OpenMayaAnim.lib")
	#pragma comment(lib,"OpenGl32.lib")
	#pragma comment(lib,"glu32.lib")
#endif

// under WIN32 we have to 'export' these functions so that they are visible
// inside the dll. If maya can't see the functions, it can't load the plugin!
#ifdef WIN32
	#define EXPORT __declspec(dllexport)
#else
	#define EXPORT
#endif


/// \brief	This function is called once when our plugin is loaded. We can use
///			it to register any custom nodes, mel functions etc.
/// \param	obj	-	a handle to the loaded plugin
/// \return	an MStatus error code
///
EXPORT MStatus initializePlugin( MObject obj )
{
	MStatus   status;

	// a classification for where the node will appear on the create menus
	// of the multilister and hypershade.
	const MString UserClassify( "shader/surface" );

	MFnPlugin plugin( obj, "Rob Bateman", "1.0", "Any");

	// register the hardware shader
	status = plugin.registerNode(BasicHwShader::m_TypeName,
								 BasicHwShader::m_TypeId,
								 BasicHwShader::creator,
								 BasicHwShader::initialize,
								 MPxNode::kHwShaderNode, &UserClassify );

	return status;
}

/// \brief	This function is called once when our plugin is unloaded. We need
/// 		to tell maya which mel funcs, nodes etc we are removing.
/// \param	obj	-	a handle to the loaded plugin
/// \return	an MStatus error code
///
EXPORT MStatus uninitializePlugin( MObject obj)
{
	MFnPlugin plugin( obj );

	// Unregister all chamelion shader nodes
	MStatus status = plugin.deregisterNode( BasicHwShader::m_TypeId );

	return status;
}
